@@ -15,91 +15,112 @@ use List::Compare;
 use List::MoreUtils qw(none uniq firstval);
 use Scalar::Util qw(weaken);
 
-our $VERSION = '1.55';
+our $VERSION = '1.56';
 
 my %translation = (
-	2  => 'Polizeiliche Ermittlung',
-	3  => 'Feuerwehreinsatz neben der Strecke',
-	4  => 'Kurzfristiger Personalausfall',
-	5  => 'Ärztliche Versorgung eines Fahrgastes',
-	6  => 'Betätigen der Notbremse',
-	7  => 'Personen im Gleis',
-	8  => 'Notarzteinsatz am Gleis',
+	1 => 'Nähere Informationen in Kürze',
+	2 => 'Polizeieinsatz',
+	3 => 'Feuerwehreinsatz auf der Strecke',
+	4 => 'Kurzfristiger Personalausfall',            # xlsx: missing
+	5 => 'Ärztliche Versorgung eines Fahrgastes',
+	6 => 'Betätigen der Notbremse',   # xlsx: "Unbefugtes Ziehen der Notbremse"
+	7  => 'Unbefugte Personen auf der Strecke',
+	8  => 'Notarzteinsatz auf der Strecke',
 	9  => 'Streikauswirkungen',
-	10 => 'Ausgebrochene Tiere im Gleis',
+	10 => 'Tiere auf der Strecke',
 	11 => 'Unwetter',
-	12 => 'Warten auf Fahrgäste aus einem Schiff',
+	12 => 'Warten auf ein verspätetes Schiff',
 	13 => 'Pass- und Zollkontrolle',
-	14 => 'Technische Störung am Bahnhof',
+	14 => 'Defekt am Bahnhof',         # xlsx: "Technischer Defekt am Bahnhof"
 	15 => 'Beeinträchtigung durch Vandalismus',
 	16 => 'Entschärfung einer Fliegerbombe',
 	17 => 'Beschädigung einer Brücke',
-	18 => 'Umgestürzter Baum im Gleis',
+	18 => 'Umgestürzter Baum auf der Strecke',
 	19 => 'Unfall an einem Bahnübergang',
-	20 => 'Tiere im Gleis',
-	21 => 'Warten auf weitere Reisende',
-	22 => 'Witterungsbedingte Störung',
-	23 => 'Feuerwehreinsatz auf Bahngelände',
-	24 => 'Verspätung aus dem Ausland',
-	25 => 'Warten auf verspätete Zugteile',
-	28 => 'Gegenstände im Gleis',
+	20 => 'Tiere im Gleis',                           # xlsx: missing
+	21 => 'Warten auf Anschlussreisende',
+	22 => 'Witterungsbedingte Beeinträchtigung',
+	23 => 'Feuerwehreinsatz auf Bahngelände',        # xlsx: missing
+	24 => 'Verspätung im Ausland',
+	25 => 'Bereitstellung weiterer Wagen',
+	26 => 'Abhängen von Wagen',
+	28 => 'Gegenstände auf der Strecke',
+	29 => 'Ersatzverkehr mit Bus ist eingerichtet',
 	31 => 'Bauarbeiten',
-	32 => 'Verzögerung beim Ein-/Ausstieg',
-	33 => 'Oberleitungsstörung',
-	34 => 'Signalstörung',
+	32 => 'Verzögerung beim Ein-/Ausstieg'
+	,    # xlsx: "Unterstützung beim Ein- und Ausstieg"
+	33 => 'Defekt an der Oberleitung',    # xlsx: "Reparatur an der Oberleitung"
+	34 => 'Defekt an einem Signal',       # xlsx: "Reparatur an einem Signal"
 	35 => 'Streckensperrung',
-	36 => 'Technische Störung am Zug',
-	37 => 'Technische Störung am Wagen',
-	38 => 'Technische Störung an der Strecke',
-	39 => 'Anhängen von zusätzlichen Wagen',
-	40 => 'Stellwerksstörung/-ausfall',
-	41 => 'Störung an einem Bahnübergang',
-	42 => 'Außerplanmäßige Geschwindigkeitsbeschränkung',
+	36 => 'Defekt am Zug',                # xlsx: "Reparatur am Zug"
+	37 => 'Defekt am Wagen',              # xlsx: missing
+	38 => 'Defekt an der Strecke',        # xlsx: "Reparatur an der Strecke"
+	39 => 'Anhängen von zusätzlichen Wagen',    # xlsx: missing
+	40 => 'Defektes Stellwerk',
+	41 => 'Defekt an einem Bahnübergang'
+	,    # xlsx: "Technischer Defekt an einem Bahnüburgang"
+	42 => 'Außerplanmäßige Geschwindigkeitsbeschränkung'
+	,    # xlsx: "Vorübergehend verminderte Geschwindigkeit auf der Strecke"
 	43 => 'Verspätung eines vorausfahrenden Zuges',
 	44 => 'Warten auf einen entgegenkommenden Zug',
-	45 => 'Überholung durch anderen Zug',
-	46 => 'Warten auf freie Einfahrt',
-	47 => 'Verspätete Bereitstellung',
+
+	# TODO for Oct 2021: switch 45, 46 to "Vorfahrt eines anderen Zuges"
+	45 =>
+	  'Überholung durch anderen Zug',    # xlsx: "Vorfahrt eines anderen Zuges"
+	46 => 'Warten auf freie Einfahrt',    # xlsx: "Vorfahrt eines anderen Zuges"
+
+	47 => 'Verspätete Bereitstellung'
+	,    # xlsx: "Verspätete Bereitstellung des Zuges"
 	48 => 'Verspätung aus vorheriger Fahrt',
-	55 => 'Technische Störung an einem anderen Zug',           # ?
-	56 => 'Warten auf Fahrgäste aus einem Bus',
-	57 => 'Zusätzlicher Halt',
-	58 => 'Umleitung',                                          # ?
+	49 => 'Kurzfristiger Personalausfall',
+	50 => 'Kurzfristige Erkrankung von Personal',
+	51 => 'Verspätetes Personal aus vorheiger Fahrt',
+	52 => 'Streik',
+	53 => 'Unwetterauswirkungen',
+	54 => 'Verfügbarkeit der Gleise derzeit eingeschränkt',
+	55 => 'Defekt an einem anderen Zug',
+	56 => 'Warten auf Anschlussreisende',                       # aus einem Bus
+	57 =>
+	  'Zusätzlicher Halt',   # xslx: "Zusätzlicher Halt zum Ein- und Ausstieg"
+	58 => 'Umleitung',        # xlsx: "Umleitung des Zuges"
 	59 => 'Schnee und Eis',
-	60 => 'Reduzierte Geschwindigkeit wegen Sturm',
-	61 => 'Türstörung',
-	62 => 'Behobene technische Störung am Zug',
+	60 => 'Witterungsbedingt verminderte Geschwindigkeit',
+	61 => 'Defekte Tür',
+	62 => 'Behobener Defekt am Zug',
 	63 => 'Technische Untersuchung am Zug',
-	64 => 'Weichenstörung',
+	64 => 'Defekt an einer Weiche',    # xlsx: "Reparatur an der Weiche"
 	65 => 'Erdrutsch',
 	66 => 'Hochwasser',
-	67 => 'Behördliche Anordnung',
+	67 => 'Behördliche Maßnahme',
+	68 => 'Hohes Fahrgastaufkommen'
+	,    # xlsx: "Hohes Fahrgastaufkommen verlängert Ein- und Ausstieg"
+	69 => 'Zug verkehrt mit verminderter Geschwindigeit',
 	70 => 'WLAN nicht verfügbar',
 	71 => 'WLAN in einzelnen Wagen nicht verfügbar',
 	72 => 'Info/Entertainment nicht verfügbar',
-	73 => 'Mehrzweckabteil vorne',
-	74 => 'Mehrzweckabteil hinten',
-	75 => '1. Klasse vorne',
-	76 => '1. Klasse hinten',
-	77 => 'Ohne 1. Klasse',
-	79 => 'Ohne Mehrzweckabteil',
-	80 => 'Abweichende Wagenreihung',
+	73 => 'Heute: Mehrzweckabteil vorne',                   # r 74
+	74 => 'Heute: Mehrzweckabteil hinten',                  # r 73
+	75 => 'Heute: 1. Klasse vorne',                         # r 76
+	76 => 'Heute: 1. Klasse hinten',                        # r 75
+	77 => '1. Klasse fehlt',
+	79 => 'Mehrzweckabteil fehlt',
+	80 => 'Andere Reihenfolge der Wagen',
 	82 => 'Mehrere Wagen fehlen',
-	83 => 'Störung der fahrzeuggebundenen Einstiegshilfe',
-	84 => 'Zug verkehrt richtig gereiht',                       # r 80 82 85
+	83 => 'Defekte fahrzeuggebundene Einstiegshilfe',
+	84 => 'Zug verkehrt richtig gereiht',                   # r 80 82 85
 	85 => 'Ein Wagen fehlt',
-	86 => 'Keine Reservierungsanzeige',
-	87 => 'Einzelne Wagen ohne Reservierungsanzeige',
+	86 => 'Gesamter Zug ohne Reservierung',
+	87 => 'Einzelne Wagen ohne Reservierung',
 	88 => 'Keine Qualitätsmängel',  # r 80 82 83 85 86 87 90 91 92 93 96 97 98
-	89 => 'Reservierungen sind wieder vorhanden',                     # -> 86 87
+	89 => 'Reservierungen sind wieder vorhanden',    # -> 86 87
 	90 => 'Kein gastronomisches Angebot',
-	91 => 'Keine Fahrradbeförderung',
+	91 => 'Fahrradmitnahme nicht möglich',
 	92 => 'Eingeschränkte Fahrradbeförderung',
-	93 => 'Fehlende oder gestörte behindertengerechte Einrichtung',
+	93 => 'Behindertengerechte Einrichtung fehlt',
 	94 => 'Ersatzbewirtschaftung',
-	95 => 'Ohne behindertengerechtes WC',
-	96 => 'Der Zug ist stark überbesetzt',                           # r 97
-	97 => 'Der Zug ist überbesetzt',                                 # r 96
+	95 => 'Universal-WC fehlt',
+	96 => 'Der Zug ist stark überbesetzt',          # r 97
+	97 => 'Der Zug ist überbesetzt',                # r 96
 	98 => 'Sonstige Qualitätsmängel',
 	99 => 'Verzögerungen im Betriebsablauf',
 
@@ -777,8 +798,11 @@ sub sched_route {
 
 sub superseded_messages {
 	my ( $self, $msg ) = @_;
-
 	my %superseded = (
+		73 => [74],
+		74 => [73],
+		75 => [76],
+		76 => [75],
 		84 => [ 80, 82, 85 ],
 		88 => [ 80, 82, 83, 85, 86, 87, 90, 91, 92, 93, 96, 97, 98 ],
 		89 => [ 86, 87 ],
@@ -841,7 +865,7 @@ arrival/departure received by Travel::Status::DE::IRIS
 
 =head1 VERSION
 
-version 1.55
+version 1.56
 
 =head1 DESCRIPTION
 
